function p = predictOneVsAll(all_theta, X)
  ##PREDICT Predict the label for a trained one-vs-all classifier. The labels 
  ##are in the range 1..K, where K = size(all_theta, 1). 
  ##  p = PREDICTONEVSALL(all_theta, X) will return a vector of predictions
  ##  for each example in the matrix X. Note that X contains the examples in
  ##  rows. all_theta is a matrix where the i-th row is a trained logistic
  ##  regression theta vector for the i-th class. You should set p to a vector
  ##  of values from 1..K (e.g., p = [1; 3; 1; 2] predicts classes 1, 3, 1, 2
  ##  for 4 examples) 

  ## Add ones to the X data matrix
  X = [ones(rows(X), 1) X];
 
  ## Index where the max is the predicted result (note we don't need the
  ## sigmoid, which gives the actual probabilities, as it doesn't affect
  ## the max)
  [junk, p] = max (X*all_theta', [], 2);

  ## Octave 3.4 and later can use the following syntax to omit output
  ## arguments
  ##
  ## [~, p] = max (X*all_theta', [], 2);

endfunction
